package com.jeeplus.test.wdt.merchantCompany.service;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jeeplus.common.redis.RedisUtils;
import com.jeeplus.sys.constant.CacheNames;
import com.jeeplus.sys.domain.DictValue;
import com.jeeplus.sys.service.DictTypeService;
import com.jeeplus.sys.service.dto.DictValueDTO;
import com.jeeplus.sys.service.mapstruct.DictValueWrapper;
import com.jeeplus.sys.utils.DictUtils;
import com.jeeplus.test.utils.MoneyUtil;
import com.jeeplus.test.wdt.merchantCompany.domain.MerchantDetails;
import com.jeeplus.test.wdt.merchantCompany.mapper.MerchantDetailsMapper;
import com.jeeplus.test.wdt.merchantCompany.service.dto.MerchantDetailsDTO;
import com.jeeplus.test.wdt.merchantCompany.service.mapstuct.MerchantDetailsWrapper;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 入驻详情service
 * @author: 徐滕
 * @version: 2024-01-04 10:56
 */
@Service
@Transactional
public class MerchantDetailsService extends ServiceImpl<MerchantDetailsMapper, MerchantDetails> {

    @Autowired
    private MerchantDetailsWrapper merchantDetailsWrapper;

    @Autowired
    private DictValueWrapper dictValueWrapper;

    @Autowired
    private DictTypeService dictTypeService;


    /**
     * 查询详情
     * @return
     */
    public MerchantDetailsDTO getLimit1() {
        MerchantDetailsDTO limit1 = baseMapper.getLimit1();
        //查询字典中数据获取方式并修改
        List<DictValueDTO> merchantDataSourcesList = DictUtils.getDictDTOList("merchant_data_sources");
        if(merchantDataSourcesList.size()>0){
            for (DictValueDTO dictValueDTO : merchantDataSourcesList) {
                if("result".equals(dictValueDTO.getLabel())){
                    if(null != limit1){
                        limit1.setDataSourcesType(dictValueDTO.getValue());
                    }
                }
            }
        }
        return limit1;
    }


    /**
     * 保存或者更新详情信息
     *
     * @param merchantDetailsDTO
     */
    public void saveOrUpdate(MerchantDetailsDTO merchantDetailsDTO) {
        MerchantDetails merchantDetails = merchantDetailsWrapper.toEntity ( merchantDetailsDTO );
        super.saveOrUpdate ( merchantDetails );
    }

    /**
     * 保存或者更新详情信息
     *
     * @param dataSources
     */
    public void saveDataSources(String dataSources) {

        Integer redisLoginNumber = (Integer) RedisUtils.getInstance ().get ( CacheNames.MERCHANTDETAILS );

        //查询字典中数据获取方式并修改
        List<DictValueDTO> merchantDataSourcesList = DictUtils.getDictDTOList("merchant_data_sources");
        if(merchantDataSourcesList.size()>0){
            for (DictValueDTO dictValueDTO : merchantDataSourcesList) {
                if("result".equals(dictValueDTO.getLabel())){
                    dictValueDTO.setValue(dataSources);
                    DictValue dictValue = dictValueWrapper.toEntity ( dictValueDTO );
                    dictTypeService.saveDictValue(dictValue);
                }
            }
        }
    }

    /**
     * 获取大屏数据并返回
     * @param type 获取数据类型
     * @param settledEnterpriseType 入驻类型
     * @return
     */
    public Map<String,String> getScreenDetail(String type,String settledEnterpriseType){
        Map<String,String> map = new HashMap<>();
        //查询字典中大屏数据获取节点信息
        String dictType = "0";
        List<DictValueDTO> merchantDataSourcesList = DictUtils.getDictDTOList("merchant_data_sources");
        if(merchantDataSourcesList.size()>0){
            for (DictValueDTO dictValueDTO : merchantDataSourcesList) {
                if("result".equals(dictValueDTO.getLabel())){
                    dictType = dictValueDTO.getValue();
                }
            }
        }
        switch (dictType){
            case "0":   //查询填写值
                //获取数据信息
                MerchantDetailsDTO info = this.getLimit1();
                if ("settledEnterpriseNumber".equals(type)) {   //入驻企业数
                    map.put("value",info.getSettledEnterpriseNumber().toString());
                }else if ("practitionerCount".equals(type)){    //电商从业人数
                    map.put("value",info.getPractitionerCount().toString());
                }else if ("annualSales".equals(type)){          //年交易额
                    map.put("value",info.getAnnualSales());
                }else if ("onlineRetailSales".equals(type)){    //网络零售额
                    map.put("value",info.getOnlineRetailSales());
                }else if ("enterNumber".equals(type)){          //抖音入驻
                    map.put("value",info.getEnterNumber());
                }
                break;

            case "1":   //计算汇总值

                if ("settledEnterpriseNumber".equals(type)) {   //入驻企业数
                    String settledEnterpriseNumber = baseMapper.getSettledEnterpriseNumber();
                    map.put("value",settledEnterpriseNumber);
                }else if ("practitionerCount".equals(type)){    //电商从业人数
                    String practitionerCount = baseMapper.getPractitionerCount();
                    map.put("value",practitionerCount);
                }else if ("annualSales".equals(type)){          //年交易额
                    String annualSales = baseMapper.getAnnualSales();
                    BigDecimal bigDecimal = MoneyUtil.toTenThousand(annualSales);
                    map.put("value",bigDecimal.toString());

                }else if ("onlineRetailSales".equals(type)){    //网络零售额
                    String onlineRetailSales = baseMapper.getOnlineRetailSales();
                    BigDecimal bigDecimal = MoneyUtil.toTenThousand(onlineRetailSales);
                    map.put("value",bigDecimal.toString());

                }else if ("enterNumber".equals(type)){          //抖音入驻
                    String enterNumber = baseMapper.getEnterNumber(settledEnterpriseType);
                    map.put("value",enterNumber);
                }
                break;
            default:
                map.put("value","0");
                break;
        }
        return map;
    }

}
